@@ -149,7 +149,7 @@ class CatBoostAlgorithm(BaseAlgorithm):
 
 
 classification_params = {
-    "learning_rate": [0.005, 0.01, 0.05, 0.1, 0.2],
+    "learning_rate": [0.05, 0.1, 0.2],
     "depth": [2, 3, 4, 5, 6],
     "rsm": [0.7, 0.8, 0.9, 1],  # random subspace method
     "subsample": [0.7, 0.8, 0.9, 1],  # random subspace method
@@ -170,7 +170,12 @@ additional = {
     "max_rows_limit": None,
     "max_cols_limit": None,
 }
-required_preprocessing = ["missing_values_inputation", "target_as_integer"]
+required_preprocessing = [
+    "missing_values_inputation",
+    "datetime_transform",
+    "text_transform",
+    "target_as_integer",
+]
 
 
 AlgorithmsRegistry.add(
@@ -193,7 +198,12 @@ AlgorithmsRegistry.add(
 
 regression_params = copy.deepcopy(classification_params)
 
-regression_required_preprocessing = ["missing_values_inputation", "target_scale"]
+regression_required_preprocessing = [
+    "missing_values_inputation",
+    "datetime_transform",
+    "text_transform",
+    "target_scale",
+]
 
 
 regression_default_params = {
