@@ -36,8 +36,9 @@ class ExtraTreesAlgorithm(SklearnTreesEnsembleClassifierAlgorithm):
         self.model = ExtraTreesClassifier(
             n_estimators=self.trees_in_step,
             criterion=params.get("criterion", "gini"),
-            max_features=params.get("max_features", 0.6),
-            min_samples_split=params.get("min_samples_split", 30),
+            max_features=params.get("max_features", 0.8),
+            max_depth=params.get("max_depth", 6),
+            min_samples_split=params.get("min_samples_split", 4),
             warm_start=True,
             n_jobs=-1,
             random_state=params.get("seed", 1),
@@ -65,8 +66,9 @@ class ExtraTreesRegressorAlgorithm(SklearnTreesEnsembleRegressorAlgorithm):
         self.model = ExtraTreesRegressor(
             n_estimators=self.trees_in_step,
             criterion=params.get("criterion", "mse"),
-            max_features=params.get("max_features", 0.8),
-            min_samples_split=params.get("min_samples_split", 4),
+            max_features=params.get("max_features", 0.6),
+            max_depth=params.get("max_depth", 6),
+            min_samples_split=params.get("min_samples_split", 30),
             warm_start=True,
             n_jobs=-1,
             random_state=params.get("seed", 1),
@@ -81,12 +83,14 @@ et_params = {
     "criterion": ["gini", "entropy"],
     "max_features": [0.5, 0.6, 0.7, 0.8, 0.9, 1.0],
     "min_samples_split": [10, 20, 30, 40, 50],
+    "max_depth": [4,6,8,10,12]
 }
 
 classification_default_params = {
     "criterion": "gini",
     "max_features": 0.6,
     "min_samples_split": 30,
+    "max_depth": 6
 }
 
 additional = {
@@ -99,6 +103,8 @@ additional = {
 required_preprocessing = [
     "missing_values_inputation",
     "convert_categorical",
+    "datetime_transform",
+    "text_transform",
     "target_as_integer",
 ]
 
@@ -131,12 +137,14 @@ regression_et_params = {
     ],  # remove "mae" because it slows down a lot https://github.com/scikit-learn/scikit-learn/issues/9626
     "max_features": [0.5, 0.6, 0.7, 0.8, 0.9, 1.0],
     "min_samples_split": [10, 20, 30, 40, 50],
+    "max_depth": [4,6,8,10,12]
 }
 
 regression_default_params = {
     "criterion": "mse",
     "max_features": 0.6,
     "min_samples_split": 30,
+    "max_depth": 6
 }
 
 regression_additional = {
@@ -149,6 +157,8 @@ regression_additional = {
 regression_required_preprocessing = [
     "missing_values_inputation",
     "convert_categorical",
+    "datetime_transform",
+    "text_transform",
     "target_scale",
 ]
 
