@@ -38,6 +38,7 @@ class RandomForestAlgorithm(SklearnTreesEnsembleClassifierAlgorithm):
             n_estimators=self.trees_in_step,
             criterion=params.get("criterion", "gini"),
             max_features=params.get("max_features", 0.8),
+            max_depth=params.get("max_depth", 6),
             min_samples_split=params.get("min_samples_split", 4),
             warm_start=True,
             n_jobs=-1,
@@ -67,6 +68,7 @@ class RandomForestRegressorAlgorithm(SklearnTreesEnsembleRegressorAlgorithm):
             n_estimators=self.trees_in_step,
             criterion=params.get("criterion", "mse"),
             max_features=params.get("max_features", 0.8),
+            max_depth=params.get("max_depth", 6),
             min_samples_split=params.get("min_samples_split", 4),
             warm_start=True,
             n_jobs=-1,
@@ -82,12 +84,14 @@ rf_params = {
     "criterion": ["gini", "entropy"],
     "max_features": [0.5, 0.6, 0.7, 0.8, 0.9, 1.0],
     "min_samples_split": [10, 20, 30, 40, 50],
+    "max_depth": [4,6,8,10,12]
 }
 
 classification_default_params = {
     "criterion": "gini",
     "max_features": 0.6,
     "min_samples_split": 30,
+    "max_depth": 6
 }
 
 
@@ -103,6 +107,8 @@ additional = {
 required_preprocessing = [
     "missing_values_inputation",
     "convert_categorical",
+    "datetime_transform",
+    "text_transform",
     "target_as_integer",
 ]
 
@@ -135,12 +141,14 @@ regression_rf_params = {
     ],  # remove "mae" because it slows down a lot https://github.com/scikit-learn/scikit-learn/issues/9626
     "max_features": [0.5, 0.6, 0.7, 0.8, 0.9, 1.0],
     "min_samples_split": [10, 20, 30, 40, 50],
+    "max_depth": [4,6,8,10,12]
 }
 
 regression_default_params = {
     "criterion": "mse",
     "max_features": 0.6,
     "min_samples_split": 30,
+    "max_depth": 6
 }
 
 regression_additional = {
@@ -155,6 +163,8 @@ regression_additional = {
 regression_required_preprocessing = [
     "missing_values_inputation",
     "convert_categorical",
+    "datetime_transform",
+    "text_transform",
     "target_scale",
 ]
 
