@@ -220,6 +220,8 @@ additional = {
 required_preprocessing = [
     "missing_values_inputation",
     "convert_categorical",
+    "datetime_transform",
+    "text_transform",
     "target_as_integer",
 ]
 
@@ -244,6 +246,8 @@ AlgorithmsRegistry.add(
 regression_required_preprocessing = [
     "missing_values_inputation",
     "convert_categorical",
+    "datetime_transform",
+    "text_transform",
     "target_scale",
 ]
 
