@@ -52,12 +52,16 @@ class ModelFramework:
 
         self._ml_task = params.get("ml_task")
         self._explain_level = params.get("explain_level")
+        self._is_stacked = params.get("is_stacked", False)
 
         self.validation = None
         self.preprocessings = []
         self.learners = []
 
         self.train_time = None
+        self.final_loss = None
+        self.metric_name = None
+        self.oof_predictions = None
         self._additional_metrics = None
         self._threshold = None  # used only for binary classifiers
 
@@ -67,7 +71,6 @@ class ModelFramework:
     def predictions(
         self, learner, preproces, X_train, y_train, X_validation, y_validation
     ):
-
         y_train_true = y_train
         y_train_predicted = learner.predict(X_train)
         y_validation_true = y_validation
@@ -114,6 +117,7 @@ class ModelFramework:
                     validation_data["y"].shape,
                 )
             )
+
             # the proprocessing is done at every validation step
             self.preprocessings += [Preprocessing(self.preprocessing_params)]
 
@@ -124,16 +128,19 @@ class ModelFramework:
                 validation_data["X"], validation_data["y"]
             )
 
+            self.learner_params["explain_level"] = self._explain_level
             self.learners += [AlgorithmFactory.get_algorithm(self.learner_params)]
             learner = self.learners[-1]
 
             self.callbacks.add_and_set_learner(learner)
             self.callbacks.on_learner_train_start()
 
+            log_to_file = os.path.join(model_path, f"learner_{k_fold+1}_training.log")
+
             for i in range(learner.max_iters):
                 self.callbacks.on_iteration_start()
 
-                learner.fit(X_train, y_train)
+                learner.fit(X_train, y_train, X_validation, y_validation, log_to_file)
 
                 self.callbacks.on_iteration_end(
                     {"iter_cnt": i},
@@ -149,8 +156,10 @@ class ModelFramework:
                 if learner.stop_training:
                     break
                 learner.update({"step": i})
+
             # end of learner iters loop
             self.callbacks.on_learner_train_end()
+
             learner.interpret(
                 X_train,
                 y_train,
@@ -171,31 +180,58 @@ class ModelFramework:
         logger.debug("ModelFramework end of training")
 
     def get_metric_name(self):
+        if self.metric_name is not None:
+            return self.metric_name
         early_stopping = self.callbacks.get("early_stopping")
         if early_stopping is None:
             return None
+        self.metric_name = early_stopping.metric.name
         return early_stopping.metric.name
 
     def get_out_of_folds(self):
+        if self.oof_predictions is not None:
+            return self.oof_predictions
         early_stopping = self.callbacks.get("early_stopping")
         if early_stopping is None:
             return None
+        self.oof_predictions = early_stopping.best_y_oof
+
+        ###############################################################
+        # in case of Neural Network and one-hot coded multiclass target
+        target_cols = [
+            c for c in self.oof_predictions.columns.tolist() if "target" in c
+        ]
+        if len(target_cols) > 1:
+            target = self.oof_predictions[target_cols[0]].copy()
+            target.name = "target"
+            for i, t in enumerate(target_cols):
+                target[self.oof_predictions[t] == 1] = i
+            self.oof_predictions.drop(target_cols, axis=1, inplace=True)
+
+            self.oof_predictions.insert(0, "target", np.array(target))
+
         return early_stopping.best_y_oof
 
     def get_final_loss(self):
+        if self.final_loss is not None:
+            return self.final_loss
         early_stopping = self.callbacks.get("early_stopping")
         if early_stopping is None:
             return None
+        self.final_loss = early_stopping.final_loss
         return early_stopping.final_loss
 
+    """
     def get_metric_logs(self):
         metric_logger = self.callbacks.get("metric_logger")
         if metric_logger is None:
             return None
         return metric_logger.loss_values
+    """
 
     def get_type(self):
-        return self.learner_params.get("model_type")
+        prefix = ""  # "Stacked" if self._is_stacked else ""
+        return prefix + self.learner_params.get("model_type")
 
     def get_name(self):
         return self._name
@@ -253,6 +289,15 @@ class ModelFramework:
     def save(self, model_path):
         logger.info(f"Save the model {model_path}")
 
+        type_of_predictions = (
+            "validation" if "k_folds" not in self.validation_params else "out_of_folds"
+        )
+        predictions_fname = os.path.join(
+            model_path, f"predictions_{type_of_predictions}.csv"
+        )
+        predictions = self.get_out_of_folds()
+        predictions.to_csv(predictions_fname, index=False)
+
         saved = []
         for i, l in enumerate(self.learners):
             p = os.path.join(model_path, f"learner_{i+1}.{l.file_extension()}")
@@ -269,20 +314,16 @@ class ModelFramework:
                 "learners": learners_params,
                 "params": self.params,
                 "saved": saved,
+                "predictions_fname": predictions_fname,
+                "metric_name": self.get_metric_name(),
+                "final_loss": self.get_final_loss(),
+                "train_time": self.get_train_time(),
+                "is_stacked": self._is_stacked,
             }
             if self._threshold is not None:
                 desc["threshold"] = self._threshold
             fout.write(json.dumps(desc, indent=4))
 
-        type_of_predictions = (
-            "validation" if "k_folds" not in self.validation_params else "out_of_folds"
-        )
-        predictions = self.get_out_of_folds()
-        predictions.to_csv(
-            os.path.join(model_path, f"predictions_{type_of_predictions}.csv"),
-            index=False,
-        )
-
         LearningCurves.plot(
             self.validation.get_n_splits(),
             self.get_metric_name(),
@@ -332,6 +373,14 @@ class ModelFramework:
         mf.uid = json_desc.get("uid", mf.uid)
         mf._name = json_desc.get("name", mf._name)
         mf._threshold = json_desc.get("threshold")
+        mf.train_time = json_desc.get("train_time", mf.train_time)
+        mf.final_loss = json_desc.get("final_loss", mf.final_loss)
+        mf.metric_name = json_desc.get("metric_name", mf.metric_name)
+        mf._is_stacked = json_desc.get("is_stacked", mf._is_stacked)
+        predictions_fname = json_desc.get("predictions_fname")
+        if predictions_fname is not None:
+            mf.oof_predictions = pd.read_csv(predictions_fname)
+
         mf.learners = []
         for learner_desc, learner_path in zip(
             json_desc.get("learners"), json_desc.get("saved")
