@@ -9,6 +9,8 @@ from supervised.preprocessing.preprocessing_missing import PreprocessingMissingV
 from supervised.preprocessing.scale import Scale
 from supervised.preprocessing.label_encoder import LabelEncoder
 from supervised.preprocessing.label_binarizer import LabelBinarizer
+from supervised.preprocessing.datetime_transformer import DateTimeTransformer
+from supervised.preprocessing.text_transformer import TextTransformer
 from supervised.preprocessing.exclude_missing_target import ExcludeRowsMissingTarget
 from supervised.algorithms.registry import (
     BINARY_CLASSIFICATION,
@@ -42,6 +44,8 @@ class Preprocessing(object):
         self._categorical = []
         self._scale = []
         self._remove_columns = []
+        self._datetime_transforms = []
+        self._text_transforms = []
 
     def _exclude_missing_targets(self, X=None, y=None):
         # check if there are missing values in target column
@@ -121,6 +125,25 @@ class Preprocessing(object):
             X_train.drop(cols_to_remove, axis=1, inplace=True)
         self._remove_columns = cols_to_remove
 
+        # there can be missing values in the text data,
+        # but we don't want to handle it by fill missing methods
+        # zeros will be imputed by text_transform method
+        cols_to_process = list(
+            filter(
+                lambda k: "text_transform" in columns_preprocessing[k],
+                columns_preprocessing,
+            )
+        )
+
+        new_text_columns = []
+        for col in cols_to_process:
+            t = TextTransformer()
+            t.fit(X_train, col)
+            X_train = t.transform(X_train)
+            self._text_transforms += [t]
+            new_text_columns += t._new_columns
+        # end of text transform
+
         for missing_method in [PreprocessingMissingValues.FILL_NA_MEDIAN]:
             cols_to_process = list(
                 filter(
@@ -133,7 +156,10 @@ class Preprocessing(object):
             X_train = missing.transform(X_train)
             self._missing_values += [missing]
 
-        for convert_method in [PreprocessingCategorical.CONVERT_INTEGER]:
+        for convert_method in [
+            PreprocessingCategorical.CONVERT_INTEGER,
+            PreprocessingCategorical.CONVERT_ONE_HOT,
+        ]:
             cols_to_process = list(
                 filter(
                     lambda k: convert_method in columns_preprocessing[k],
@@ -145,6 +171,23 @@ class Preprocessing(object):
             X_train = convert.transform(X_train)
             self._categorical += [convert]
 
+        # datetime transform
+        cols_to_process = list(
+            filter(
+                lambda k: "datetime_transform" in columns_preprocessing[k],
+                columns_preprocessing,
+            )
+        )
+
+        new_datetime_columns = []
+        for col in cols_to_process:
+
+            t = DateTimeTransformer()
+            t.fit(X_train, col)
+            X_train = t.transform(X_train)
+            self._datetime_transforms += [t]
+            new_datetime_columns += t._new_columns
+
         # SCALE
         for scale_method in [Scale.SCALE_NORMAL, Scale.SCALE_LOG_AND_NORMAL]:
             cols_to_process = list(
@@ -153,6 +196,19 @@ class Preprocessing(object):
                     columns_preprocessing,
                 )
             )
+            if (
+                len(cols_to_process)
+                and len(new_datetime_columns)
+                and scale_method == Scale.SCALE_NORMAL
+            ):
+                cols_to_process += new_datetime_columns
+            if (
+                len(cols_to_process)
+                and len(new_text_columns)
+                and scale_method == Scale.SCALE_NORMAL
+            ):
+                cols_to_process += new_text_columns
+
             if len(cols_to_process):
                 scale = Scale(cols_to_process)
                 scale.fit(X_train)
@@ -213,6 +269,11 @@ class Preprocessing(object):
             ]
             X_validation.drop(cols_to_remove, axis=1, inplace=True)
 
+        # text transform
+        for tt in self._text_transforms:
+            if X_validation is not None and tt is not None:
+                X_validation = tt.transform(X_validation)
+
         for missing in self._missing_values:
             if X_validation is not None and missing is not None:
                 X_validation = missing.transform(X_validation)
@@ -241,6 +302,11 @@ class Preprocessing(object):
         for convert in self._categorical:
             if X_validation is not None and convert is not None:
                 X_validation = convert.transform(X_validation)
+
+        for dtt in self._datetime_transforms:
+            if X_validation is not None and dtt is not None:
+                X_validation = dtt.transform(X_validation)
+
         for scale in self._scale:
             if X_validation is not None and scale is not None:
                 X_validation = scale.transform(X_validation)
@@ -369,6 +435,21 @@ class Preprocessing(object):
                     cats += [cat.to_json()]
             if cats:
                 preprocessing_params["categorical"] = cats
+
+        if self._datetime_transforms is not None and len(self._datetime_transforms):
+            dtts = []
+            for dtt in self._datetime_transforms:
+                dtts += [dtt.to_json()]
+            if dtts:
+                preprocessing_params["datetime_transforms"] = dtts
+
+        if self._text_transforms is not None and len(self._text_transforms):
+            tts = []
+            for tt in self._text_transforms:
+                tts += [tt.to_json()]
+            if tts:
+                preprocessing_params["text_transforms"] = tts
+
         if self._scale is not None and len(self._scale):
             scs = [sc.to_json() for sc in self._scale if sc.to_json()]
             if scs:
@@ -400,6 +481,21 @@ class Preprocessing(object):
                 cat = PreprocessingCategorical()
                 cat.from_json(cat_data)
                 self._categorical += [cat]
+
+        if "datetime_transforms" in data_json:
+            self._datetime_transforms = []
+            for dtt_params in data_json["datetime_transforms"]:
+                dtt = DateTimeTransformer()
+                dtt.from_json(dtt_params)
+                self._datetime_transforms += [dtt]
+
+        if "text_transforms" in data_json:
+            self._text_transforms = []
+            for tt_params in data_json["text_transforms"]:
+                tt = TextTransformer()
+                tt.from_json(tt_params)
+                self._text_transforms += [tt]
+
         if "scale" in data_json:
             self._scale = []
             for scale_data in data_json["scale"]:
